@@ -13,4 +13,4 @@ class GraphGroupViewSet(viewsets.ModelViewSet):
 class GraphViewSet(viewsets.ModelViewSet):
 	queryset = models.Graph.objects.all()
 	serializer_class = serializers.GraphSerializer
-	renderer_classes = api_settings.DEFAULT_RENDERER_CLASSES + [renderers.PNGRenderer, ]
+	renderer_classes = api_settings.DEFAULT_RENDERER_CLASSES + [renderers.PNGRenderer, renderers.SVGRenderer, ]
